@@ -12,8 +12,7 @@ from rest_framework.serializers import (
 
 from .exceptions import FieldNotFound, QueryFormatError
 from .fields import (
-    BaseReplaceableNestedField, BaseRESTQLNestedField,
-    BaseWritableNestedField, DynamicSerializerMethodField
+    BaseRESTQLNestedField, DynamicSerializerMethodField
 )
 from .operations import ADD, CREATE, REMOVE, UPDATE
 from .parser import Parser
@@ -676,17 +675,15 @@ class NestedCreateMixin(BaseNestedMixin):
                 field_serializer = nested_fields[field]
 
             if isinstance(field_serializer, Serializer):
-                if isinstance(field_serializer, BaseReplaceableNestedField):
+                if field_serializer.is_replaceable:
                     value = validated_data.pop(field)
                     fields["foreignkey_related"]["replaceable"] \
                         .update({field: value})
-                elif isinstance(field_serializer, BaseWritableNestedField):
+                else:
                     value = validated_data.pop(field)
                     fields["foreignkey_related"]["writable"]\
                         .update({field: value})
-            elif isinstance(field_serializer, ListSerializer) and \
-                    isinstance(field_serializer, BaseWritableNestedField):
-
+            elif isinstance(field_serializer, ListSerializer):
                 model = self.Meta.model
                 rel = getattr(model, field).rel
 
@@ -964,17 +961,15 @@ class NestedUpdateMixin(BaseNestedMixin):
                 field_serializer = nested_fields[field]
 
             if isinstance(field_serializer, Serializer):
-                if isinstance(field_serializer, BaseReplaceableNestedField):
+                if field_serializer.is_replaceable:
                     value = validated_data.pop(field)
                     fields["foreignkey_related"]["replaceable"] \
                         .update({field: value})
-                elif isinstance(field_serializer, BaseWritableNestedField):
+                else:
                     value = validated_data.pop(field)
                     fields["foreignkey_related"]["writable"] \
                         .update({field: value})
-            elif (isinstance(field_serializer, ListSerializer) and
-                    (isinstance(field_serializer, BaseWritableNestedField) or
-                     isinstance(field_serializer, BaseReplaceableNestedField))):
+            elif isinstance(field_serializer, ListSerializer):
                 model = self.Meta.model
                 rel = getattr(model, field).rel
 
